[Python-checkins] r88728 - in python/branches/release27-maint: Lib/asyncore.py Misc/NEWS

giampaolo.rodola python-checkins at python.org
Thu Mar 3 15:17:51 CET 2011


Author: giampaolo.rodola
Date: Thu Mar  3 15:17:51 2011
New Revision: 88728

Log:
Merged revisions 88722 via svnmerge from 
svn+ssh://pythondev@svn.python.org/python/branches/py3k

........
  r88722 | giampaolo.rodola | 2011-03-03 14:57:47 +0100 (gio, 03 mar 2011) | 1 line
  
  Fix issue 11265: asyncore now correctly handles EPIPE, EBADF and EAGAIN errors on accept(), recv() and send().
........


Modified:
   python/branches/release27-maint/   (props changed)
   python/branches/release27-maint/Lib/asyncore.py
   python/branches/release27-maint/Misc/NEWS

Modified: python/branches/release27-maint/Lib/asyncore.py
==============================================================================
--- python/branches/release27-maint/Misc/NEWS	(original)
+++ python/branches/release27-maint/Misc/NEWS	Thu Mar  3 15:17:51 2011
@@ -37,6 +37,9 @@
 Library
 -------
 
+- Issue #11265: asyncore now correctly handles EPIPE, EBADF and EAGAIN errors
+  on accept(), send() and recv().
+
 - Issue #11326: Add the missing connect_ex() implementation for SSL sockets,
   and make it work for non-blocking connects.
 


More information about the Python-checkins mailing list
--- python/branches/release27-maint/Lib/asyncore.py	(original)
+++ python/branches/release27-maint/Lib/asyncore.py	Thu Mar  3 15:17:51 2011
@@ -54,7 +54,11 @@
 
 import os
 from errno import EALREADY, EINPROGRESS, EWOULDBLOCK, ECONNRESET, EINVAL, \
-     ENOTCONN, ESHUTDOWN, EINTR, EISCONN, EBADF, ECONNABORTED, errorcode
+     ENOTCONN, ESHUTDOWN, EINTR, EISCONN, EBADF, ECONNABORTED, EPIPE, EAGAIN, \
+     errorcode
+
+_DISCONNECTED = frozenset((ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED, EPIPE,
+                           EBADF))
 
 try:
     socket_map
@@ -109,7 +113,7 @@
         if flags & (select.POLLHUP | select.POLLERR | select.POLLNVAL):
             obj.handle_close()
     except socket.error, e:
-        if e.args[0] not in (EBADF, ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED):
+        if e.args[0] not in _DISCONNECTED:
             obj.handle_error()
         else:
             obj.handle_close()
@@ -353,7 +357,7 @@
         except TypeError:
             return None
         except socket.error as why:
-            if why.args[0] in (EWOULDBLOCK, ECONNABORTED):
+            if why.args[0] in (EWOULDBLOCK, ECONNABORTED, EAGAIN):
                 return None
             else:
                 raise
@@ -367,7 +371,7 @@
         except socket.error, why:
             if why.args[0] == EWOULDBLOCK:
                 return 0
-            elif why.args[0] in (ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED):
+            elif why.args[0] in _DISCONNECTED:
                 self.handle_close()
                 return 0
             else:
@@ -385,7 +389,7 @@
                 return data
         except socket.error, why:
             # winsock sometimes throws ENOTCONN
-            if why.args[0] in [ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED]:
+            if why.args[0] in _DISCONNECTED:
                 self.handle_close()
                 return ''
             else:

Modified: python/branches/release27-maint/Misc/NEWS
==============================================================================